@@ -3,7 +3,7 @@
 from .bruteforce_lib import *
 from .invert import *
 
-
+from dolo.compiler.model import Model
 from dolo.numeric.decision_rule import DecisionRule
 from dolo.misc.itprinter import IterationsPrinter
 from numba import jit
@@ -46,7 +46,7 @@ def smooth(res, dres, jres, dx, pos=1.0):
     # jres is modified
     dinf = dx > 100000
     n_m, N, n_x = res.shape
-    sq = sqrt(res ** 2 + (dx) ** 2)
+    sq = sqrt(res**2 + (dx) ** 2)
     H = res + (dx) - sq
     Phi_a = 1 - res / sq
     Phi_b = 1 - (dx) / sq
@@ -67,7 +67,7 @@ def smooth_nodiff(res, dx):
 
     n_m, N, n_x = res.shape
     dinf = dx > 100000
-    sq = sqrt(res ** 2 + (dx) ** 2)
+    sq = sqrt(res**2 + (dx) ** 2)
     H = res + (dx) - sq
     H[dinf] = res[dinf]
     return H
@@ -215,7 +215,7 @@ def radius_jac(res, dres, jres, fut_S, dumdr, tol=1e-10, maxit=1000, verbose=Fal
 
     err0 = 0.0
 
-    norm2 = lambda m: sqrt((m ** 2).sum())
+    norm2 = lambda m: sqrt((m**2).sum())
 
     import numpy.random
 
@@ -248,22 +248,33 @@ from .results import AlgoResult, ImprovedTimeIterationResult
 
 
 def improved_time_iteration(
-    model,
+    model: Model,
+    *,
+    dr0: DecisionRule = None,  #
+    verbose: bool = True,  #
+    details: bool = True,  #
+    ignore_constraints=False,  #
     method="jac",
-    dr0=None,
     dprocess=None,
     interp_method="cubic",
     mu=2,
     maxbsteps=10,
-    verbose=False,
     tol=1e-8,
     smaxit=500,
     maxit=1000,
-    complementarities=True,
     compute_radius=False,
     invmethod="iti",
-    details=True,
-):
+    # obsolete
+    complementarities=None
+) -> ImprovedTimeIterationResult:
+
+    # obsolete
+    if complementarities is not None:
+        # TODO: warning
+        pass
+    else:
+        complementarities = not ignore_constraints
+
     def vprint(*args, **kwargs):
         if verbose:
             print(*args, **kwargs)
