@@ -18,6 +18,18 @@ class TimeIterationResult(AlgoResult):
     trace: object  # {Nothing,IterationTrace}
 
 
+@dataclass
+class EGMResult(AlgoResult):
+    dr: object
+    iterations: int
+    dprocess: object
+    a_converged: bool
+    a_tol: float
+    err: float
+    # log: object  # TimeIterationLog
+    # trace: object  # {Nothing,IterationTrace}
+
+
 @dataclass
 class ValueIterationResult(AlgoResult):
     dr: object  #:AbstractDecisionRule
