@@ -2,6 +2,8 @@ import numpy
 import pandas
 import xarray as xr
 import numpy as np
+
+from dolo.compiler.model import Model
 from dolo.numeric.optimize.ncpsolve import ncpsolve
 from dolo.numeric.optimize.newton import newton as newton_solver
 from dolo.numeric.optimize.newton import SerialDifferentiableFunction
@@ -24,8 +26,12 @@ def response(model, dr, varname, T=40, impulse: float = None):
     e1 = numpy.zeros(len(model.symbols["exogenous"]))
     e1[i_exo] = impulse
 
-    m_simul = model.exogenous.response(T, e1)
-    m_simul = m_simul[:, None, :]
+    exogenous = model.exogenous
+    print(exogenous)
+    print(T, e1)
+    m_simul = model.exogenous.response(T - 1, e1)  # this is an xarray T x V
+    m_simul = m_simul.expand_dims("N")
+    m_simul = m_simul.transpose("T", "N", "V").data
 
     sim = simulate(model, dr, N=1, T=T, driving_process=m_simul, stochastic=False)
 
@@ -49,11 +55,13 @@ def find_index(sim, values):
 
 from dolo.numeric.grids import CartesianGrid, UnstructuredGrid
 from dolo.algos.results import AlgoResult
+from dolo.numeric.decision_rule import DecisionRule
 
 
 def simulate(
-    model,
-    dr,
+    model: Model,
+    dr: DecisionRule,
+    *,
     process=None,
     N=1,
     T=40,
@@ -64,8 +72,7 @@ def simulate(
     seed=42,
     stochastic=True,
 ):
-    """
-    Simulate a model using the specified decision rule.
+    """Simulate a model using the specified decision rule.
 
     Parameters
     ----------
