@@ -9,14 +9,14 @@ import xarray
 
 
 def eval_formula(expr: str, dataframe=None, context=None):
-    '''
+    """
     expr: string
         Symbolic expression to evaluate.
         Example: `k(1)-delta*k(0)-i`
     table: (optional) pandas dataframe
         Each column is a time series, which can be indexed with dolo notations.
     context: dict or CalibrationDict
-    '''
+    """
 
     if context is None:
         dd = {}  # context dictionary
@@ -33,19 +33,19 @@ def eval_formula(expr: str, dataframe=None, context=None):
     variables = list_variables(expr_ast)
     nexpr = stringify(expr_ast)
 
-
-    dd['log'] = log
-    dd['exp'] = exp
+    dd["log"] = log
+    dd["exp"] = exp
 
     if dataframe is not None:
 
         import pandas as pd
+
         for (k, t) in variables:
             dd[stringify_symbol((k, t))] = dataframe[k].shift(t)
-        dd['t_'] = pd.Series(dataframe.index, index=dataframe.index)
+        dd["t_"] = pd.Series(dataframe.index, index=dataframe.index)
 
     expr = str_expression(nexpr)
 
-    res = eval(expr.replace('^','**'), dd)
+    res = eval(expr.replace("^", "**"), dd)
 
     return res
