@@ -237,7 +237,7 @@ class SymbolicModel:
                     assert k.children[1].children[0].value == "0"
 
                     vv = definitions.value[i][1]
-                    v = parse_string(vv, start="formula")
+                    v = parse_string(vv)
                     v = sanitize(v, variables=vars)
                     v = str_expression(v)
 
@@ -254,15 +254,22 @@ class SymbolicModel:
     @property
     def name(self):
         try:
-            self.data["name"].value
+            return self.data["name"].value
         except Exception as e:
             return "Anonymous"
 
+    @property
+    def filename(self):
+        try:
+            return self.data["filename"].value
+        except Exception as e:
+            return "<string>"
+
     @property
     def infos(self):
         infos = {
             "name": self.name,
-            "filename": self.data.get("filename", "<string>"),
+            "filename": self.filename,
             "type": "dtcc",
         }
         return infos
