@@ -1,4 +1,4 @@
-__author__ = 'pablo'
+__author__ = "pablo"
 
 
 from .discretization import *
