@@ -1,7 +1,13 @@
 def test_grids():
 
-    from dolo.numeric.grids import UniformCartesianGrid, UnstructuredGrid, NonUniformCartesianGrid, SmolyakGrid
+    from dolo.numeric.grids import (
+        UniformCartesianGrid,
+        UnstructuredGrid,
+        NonUniformCartesianGrid,
+        SmolyakGrid,
+    )
     from dolo.numeric.grids import n_nodes, nodes, node
+
     print("Cartsian Grid")
     grid = UniformCartesianGrid([0.1, 0.3], [9, 0.4], [50, 10])
     print(grid.nodes)
@@ -10,14 +16,13 @@ def test_grids():
     print("UnstructuredGrid")
     ugrid = UnstructuredGrid([[0.1, 0.3], [9, 0.4], [50, 10]])
     print(nodes(ugrid))
-    print(node(ugrid,0))
+    print(node(ugrid, 0))
     print(n_nodes(ugrid))
 
-
     print("Non Uniform CartesianGrid")
     ugrid = NonUniformCartesianGrid([[0.1, 0.3], [9, 0.4], [50, 10]])
     print(nodes(ugrid))
-    print(node(ugrid,0))
+    print(node(ugrid, 0))
     print(n_nodes(ugrid))
 
     print("Smolyak Grid")
